@@ -1,7 +1,8 @@
 #' Look up options for parameters passed to each source
 #'
+#' @export
 #' @param from (character) Data source to get data from, any combination of gbif, bison,
-#' ebird, AntWeb, and/or ecoengine. Case doesn't matter. inat is not included here,
+#' ebird, AntWeb, idigibio and/or ecoengine. Case doesn't matter. inat is not included here,
 #' see that package's help docs.
 #' @param where (character) One of console (print to console) or html (opens help page, if in
 #' non-interactive R session, prints help to console).
@@ -12,7 +13,6 @@
 #'
 #' Note that the from parameter is lowercased within the function and is called through
 #' match.arg first, so you can match on unique partial strings too (e.g., 'e' for 'ecoengine').
-#' @export
 #' @examples \dontrun{
 #' # opens up documentation for this function
 #' occ_options()
@@ -24,6 +24,7 @@
 #' occ_options('antweb')
 #' occ_options('ebird')
 #' occ_options('bison')
+#' occ_options('idigbio')
 #'
 #' # Or open in html version
 #' occ_options('bison', 'html')
@@ -31,24 +32,27 @@
 
 occ_options <- function(from = 'gbif', where="console"){
   from <- tolower(from)
-  from <- match.arg(from, choices=c('gbif','bison','ebird','ecoengine','antweb'))
-  pkgname <- switch(from, gbif='rgbif', bison='rbison', ebird='rebird', ecoengine='ecoengine', antweb='AntWeb')
-  fxn <- switch(from, gbif='occ_search', bison='bison', ebird='ebirdregion', ecoengine='ee_observations', antweb='aw_data')
-  if(where == "console"){
+  from <- match.arg(from, choices = c('gbif', 'bison', 'ebird', 'ecoengine', 'antweb', 'idigbio'))
+  pkgname <- switch(from, gbif = 'rgbif', bison = 'rbison', ebird = 'rebird', 
+                    ecoengine = 'ecoengine', antweb = 'AntWeb', idigbio = 'ridigbio')
+  fxn <- switch(from, gbif = 'occ_search', bison = 'bison', ebird = 'ebirdregion', 
+                ecoengine = 'ee_observations', antweb = 'aw_data', idigbio = 'idig_search_records')
+  if (where == "console") {
     res <- tools::Rd_db(pkgname)
     fxnrd <- res[[sprintf('%s.Rd', fxn)]]
     params <- fxnrd[ which(rd_tags(fxnrd) == "\\arguments") ]
     pars <- unlist(sc(sapply(params[[1]], function(x){
-      if(!x[[1]] == "\n" && nchar(strtrim(x[[1]])) != 0) paste(x[[1]], gsub("\n", "", paste(unlist(x[[2]]), collapse = " ") ), sep = " - ")
+      if (!x[[1]] == "\n" && nchar(strtrim(x[[1]])) != 0) paste(x[[1]], gsub("\n", "", paste(unlist(x[[2]]), collapse = " ") ), sep = " - ")
     })))
-    cat(sprintf("%s parameters:", fxn), sapply(pars, spocc_wrap, indent=6, width=80, USE.NAMES = FALSE), sep = "\n")
+    cat(sprintf("%s parameters:", fxn), sapply(pars, spocc_wrap, indent = 6, width = 80, USE.NAMES = FALSE), sep = "\n")
   } else {
     showit <- switch(from,
                      gbif = "?rgbif::occ_search",
                      bison = "?rbison::bison",
                      ebird = "?rebird::ebirdregion",
                      ecoengine = "?ecoengine::ee_observations",
-                     antweb = "?AntWeb::aw_data")
+                     antweb = "?AntWeb::aw_data",
+                     idigbio = "?ridigbio::idig_search_records")
     eval(parse(text = showit))
   }
 }
